==> erpmc-0.2.0.tar.gz: lib/permission_management/branch_user/model/model.dart <==
part of '../../../permission_management.dart';

@Entity(
  tableName: 'branch_user',
  primaryKeys: [
    'branch_id',
    'user_id',
  ],
  foreignKeys: [
    ForeignKey(
      childColumns: ['branch_id'],
      parentColumns: ['id'],
      entity: BranchModel,
    ),
    ForeignKey(
      childColumns: ['user_id'],
      parentColumns: ['id'],
      entity: UserModel,
    ),
    ForeignKey(
      childColumns: ['user_role_id'],
      parentColumns: ['id'],
      entity: UserRoleModel,
    ),
  ],
)
class BranchUserModel extends Model {
  @ColumnInfo(name: 'user_id')
  final int userId;
  static const String userIdTag = "userId";

  @ColumnInfo(name: 'branch_id')
  final int branchId;
  static const String branchIdTag = "branchId";

  @ColumnInfo(name: 'role_id')
  final int roleId;
  static const String roleIdTag = "roleId";

  final bool status;
  static const String statusTag = "status";

  /// primary key
  @override
  List<Object?> get props => [userId, branchId];
  const BranchUserModel({
    required this.userId,
    required this.branchId,
    required this.roleId,
    this.status = false,
  });
  BranchUserModel.fromMap(super.map)
      : userId = map.getInt(userIdTag)!,
        branchId = map.getInt(branchIdTag)!,
        roleId = map.getInt(roleIdTag)!,
        status = map.getBool(statusTag)!,
        super.fromMap();

  @override
  Map<String, dynamic> toMap() => {
        userIdTag: userId,
        branchIdTag: branchId,
        roleIdTag: roleId,
        statusTag: status,
      };
}

extension BranchUserModelExtension<ModelType extends BranchUserModel>
    on Iterable<ModelType> {}

==> erpmc-0.2.1.tar.gz: lib/permission_management/branch_user/model/model.dart <==
part of '../../../permission_management.dart';

@Entity(
  tableName: 'branch_user',
  primaryKeys: [
    'branch_id',
    'user_id',
  ],
  foreignKeys: [
    ForeignKey(
      childColumns: ['branch_id'],
      parentColumns: ['id'],
      entity: BranchModel,
    ),
    ForeignKey(
      childColumns: ['user_id'],
      parentColumns: ['id'],
      entity: UserModel,
    ),
    ForeignKey(
      childColumns: ['role_id'],
      parentColumns: ['id'],
      entity: UserRoleModel,
    ),
  ],
)
class BranchUserModel extends Model {
  @ColumnInfo(name: 'user_id')
  final int userId;
  static const String userIdTag = "userId";

  @ColumnInfo(name: 'branch_id')
  final int branchId;
  static const String branchIdTag = "branchId";

  @ColumnInfo(name: 'role_id')
  final int roleId;
  static const String roleIdTag = "roleId";

  final bool status;
  static const String statusTag = "status";

  /// primary key
  @override
  List<Object?> get props => [userId, branchId];
  const BranchUserModel({
    required this.userId,
    required this.branchId,
    required this.roleId,
    this.status = false,
  });
  BranchUserModel.fromMap(super.map)
      : userId = map.getInt(userIdTag)!,
        branchId = map.getInt(branchIdTag)!,
        roleId = map.getInt(roleIdTag)!,
        status = map.getBool(statusTag)!,
        super.fromMap();

  @override
  Map<String, dynamic> toMap() => {
        userIdTag: userId,
        branchIdTag: branchId,
        roleIdTag: roleId,
        statusTag: status,
      };
}

extension BranchUserModelExtension<ModelType extends BranchUserModel>
    on Iterable<ModelType> {}
